==> qmmp-0.6.4.tar.bz2: qmmp-0.6.4/src/plugins/Effect/srconverter/translations/srconverter_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/plugins/Effect/srconverter/translations/srconverter_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="31"/>
        <source>SRC Plugin</source>
        <translation>Wtyczka SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>O wtyczce Sample Rate Converter</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="53"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Wtyczka Sample Rate Converter dla Qmmp</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Ustawienia wtyczki Sample Rate Converter</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Próbkowanie (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Rodzaj interpolacji:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>SINC (najlepsza jakość)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>SINC (średnia jakość)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>SINC (najszybsza)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>Interpolacja (ZOH)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>Interpolacja liniowa</translation>
    </message>
</context>
</TS>
